@@ -36,9 +36,4 @@ def canonical_triplets(A,B):  # Laver tuples med element fra A som 0'te indgang
 
 # Opgave 5
 def anchored_triplets(L, R):  # Sammensætter to tuples
-    return canonical_triplets(L, R)+canonical_triplets(R, L)
-
-J = gen_labels_letter(5)
-K = gen_labels(5)
-print(pairs(J))
-print(pairs(K))
\ No newline at end of file
+    return canonical_triplets(L, R)+canonical_triplets(R, L)
\ No newline at end of file
